@@ -1,22 +1,21 @@
 use v6;
 
-use PDF:ver(v0.3.2+);
+use PDF:ver(v0.3.8);
 
 #| PDF entry-point. either a trailer dict or an XRef stream
-class PDF::Class:ver<0.3.8>#:api<PDF-1.7>
+class PDF::Class:ver<0.3.9>#:api<PDF-1.7>
     is PDF {
-    # See [PDF 32000 Table 15 - Entries in the file trailer dictionary]
     # base class declares: $.Size, $.Encrypt, $.ID
-    ## use ISO_32000::File_trailer;
-    ## also does ISO_32000::File_trailer;
+    # use ISO_32000::Table_15-Entries_in_the_file_trailer_dictionary;
+    # also does ISO_32000::Table_15-Entries_in_the_file_trailer_dictionary;
 
     use PDF::Content;
     use PDF::COS::Tie;
     use PDF::Class::Type;
     use PDF::Info;
     has PDF::Info $.Info is entry(:indirect);  # (Optional; must be an indirect reference) The document’s information dictionary
-    my subset Catalog of PDF::Class::Type where { .<Type> ~~ 'Catalog' };  # autoloaded PDF::Catalog
-    has Catalog $.Root is entry(:required, :indirect, :alias<catalog>);
+    my subset CatalogLike of PDF::Class::Type where { .<Type> ~~ 'Catalog' };  # autoloaded PDF::Catalog
+    has CatalogLike $.Root is entry(:required, :indirect, :alias<catalog>);
 
     method type { 'PDF' }
     method version is rw {
@@ -31,12 +30,8 @@ class PDF::Class:ver<0.3.8>#:api<PDF-1.7>
         );
     }
 
-    method open(|c) {
-	my $doc = callsame;
-	die "PDF file has wrong type: " ~ $doc.reader.type
-	    unless $doc.reader.type eq 'PDF';
-	$doc;
-    }
+    # make sure it really is a PDF, not an FDF file etc
+    method open(|c) { nextwith( :type<PDF>, |c); }
 
     method save-as($spec, Bool :$info = True, |c) {
 
@@ -50,7 +45,7 @@ class PDF::Class:ver<0.3.8>#:api<PDF-1.7>
             else {
                 # creating
                 $Info.Producer  //= "{self.WHAT.perl}{with self.^ver { ":v$_" } else { '' }}";
-                $Info.Creator   //= "{$*PERL}:v{$*PERL.version}, PDF::Class:v{self.^ver}, PDF::Content:v{PDF::Content.^ver}, PDF:v{PDF.^ver}";
+                $Info.Creator   //= "Raku:v{$*PERL.version}, PDF::Class:v{self.^ver}, PDF::Content:v{PDF::Content.^ver}, PDF:v{PDF.^ver}";
                 $Info.CreationDate //= $now
             }
         }
@@ -86,7 +81,7 @@ class PDF::Class:ver<0.3.8>#:api<PDF-1.7>
         }
     }
 
-    my subset Pages of PDF::Class::Type where { .<Type> ~~ 'Pages' }; # autoloaded PDF::Pages
-    method Pages returns Pages handles <page pages add-page delete-page insert-page page-count page-index media-box crop-box bleed-box trim-box art-box core-font use-font rotate> { self.Root.Pages }
+    my subset PagesLike of PDF::Class::Type where { .<Type> ~~ 'Pages' }; # autoloaded PDF::Pages
+    method Pages returns PagesLike handles <page pages add-page delete-page insert-page page-count page-index media-box crop-box bleed-box trim-box art-box core-font use-font rotate> { self.Root.Pages }
 
 }
