@@ -5,9 +5,8 @@ use PDF::COS::Tie::Hash;
 role PDF::NameTree
     does PDF::COS::Tie::Hash {
 
-    # See [PDF 32000 Table 36 - Entries in a name tree node dictionary]
-    ## use ISO_32000::Name_tree_node;
-    ## also does ISO_32000::Name_tree_node;
+    # use ISO_32000::Table_36-Entries_in_a_name_tree_node_dictionary;
+    # also does ISO_32000::Table_36-Entries_in_a_name_tree_node_dictionary;
 
     use PDF::COS;
     #| a lightweight tied hash to fetch objects from a Name Tree
@@ -24,9 +23,9 @@ role PDF::NameTree
                 unless %!fetched{$node}++ {
                     for 0, 2 ...^ +$kv {
                         my $val = $kv[$_ + 1];
-                        $!root.coerce-node($val)
-                            if $!root.coerce-nodes;
-                        %!values{ $kv[$_] } = $val;
+                      .($val, $!root.of)
+                           with $!root.coercer;
+                         %!values{ $kv[$_] } = $val;
                     }
                 }
             }
@@ -71,7 +70,7 @@ role PDF::NameTree
 
     has Str @.Limits is entry(:len(2)); # Intermediate and leaf nodes only; required) Shall be an array of two strings, that shall specify the (lexically) least and greatest keys included in the Names array of a leaf node or in the Names arrays of any leaf nodes that are descendants of an intermediate node.
 
-    method coerce-nodes {False}
+    method coercer {Mu}
 }
 
 role PDF::NameTree[
@@ -81,9 +80,6 @@ role PDF::NameTree[
     },
 ] does PDF::NameTree {
     method of {$type}
-    method coerce-nodes {True}
-    method coerce-node($node is rw) {
-        &coerce($node, $type);
-    }
+    method coercer { &coerce; }
 }
 
